==> SuiteCRM-8.8.0.zip: core/backend/Data/Service/Record/Mappers/ModuleMapperTrait.php <==
<?php
/**
 * SuiteCRM is a customer relationship management program developed by SalesAgility Ltd.
 * Copyright (C) 2024 SalesAgility Ltd.
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SALESAGILITY, SALESAGILITY DISCLAIMS THE
 * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * In accordance with Section 7(b) of the GNU Affero General Public License
 * version 3, these Appropriate Legal Notices must retain the display of the
 * "Supercharged by SuiteCRM" logo. If the display of the logos is not reasonably
 * feasible for technical reasons, the Appropriate Legal Notices must display
 * the words "Supercharged by SuiteCRM".
 */


namespace App\Data\Service\Record\Mappers;

trait ModuleMapperTrait
{

    /**
     * @param array $parentMap
     * @param int $order
     * @param BaseModuleMapperInterface $handler
     * @return void
     */
    protected function addMapperByOrder(array &$parentMap, int $order, BaseModuleMapperInterface $handler): void
    {
        $mappersByOrder = $parentMap[$order] ?? [];
        $mappersByOrder[] = $handler;
        $parentMap[$order] = $mappersByOrder;
    }

    /**
     * @param array $mapperModes
     * @param string $mode
     * @return bool
     */
    protected function isModeEnabled(array $mapperModes, string $mode): bool
    {
        $modeEnabled = false;
        if (in_array($mode, $mapperModes, true)) {
            $modeEnabled = true;
        }
        return $modeEnabled;
    }

    /**
     * @param array $mappers
     * @param string $mode
     * @return array
     */
    protected function filterMappersByModes(array $mappers, string $mode): array
    {
        if (empty($mode)) {
            return $mappers;
        }

        $modeMappers = [];
        foreach ($mappers as $mapper) {
            $mapperModes = $mapper->getModes();

            $modeEnabled = $this->isModeEnabled($mapperModes, $mode);

            if ($modeEnabled) {
                $modeMappers[] = $mapper;
            }
        }
        return $modeMappers;
    }


}

==> SuiteCRM-8.9.1.zip: core/backend/Data/Service/Record/Mappers/ModuleMapperTrait.php <==
<?php
/**
 * SuiteCRM is a customer relationship management program developed by SuiteCRM Ltd.
 * Copyright (C) 2024 SuiteCRM Ltd.
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUITECRM, SUITECRM DISCLAIMS THE
 * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * In accordance with Section 7(b) of the GNU Affero General Public License
 * version 3, these Appropriate Legal Notices must retain the display of the
 * "Supercharged by SuiteCRM" logo. If the display of the logos is not reasonably
 * feasible for technical reasons, the Appropriate Legal Notices must display
 * the words "Supercharged by SuiteCRM".
 */


namespace App\Data\Service\Record\Mappers;

trait ModuleMapperTrait
{

    /**
     * @param array $parentMap
     * @param int $order
     * @param BaseModuleMapperInterface $handler
     * @return void
     */
    protected function addMapperByOrder(array &$parentMap, int $order, BaseModuleMapperInterface $handler): void
    {
        $mappersByOrder = $parentMap[$order] ?? [];
        $mappersByOrder[] = $handler;
        $parentMap[$order] = $mappersByOrder;
    }

    /**
     * @param array $mapperModes
     * @param string $mode
     * @return bool
     */
    protected function isModeEnabled(array $mapperModes, string $mode): bool
    {
        $modeEnabled = false;
        if (in_array($mode, $mapperModes, true)) {
            $modeEnabled = true;
        }
        return $modeEnabled;
    }

    /**
     * @param array $mappers
     * @param string $mode
     * @return array
     */
    protected function filterMappersByModes(array $mappers, string $mode): array
    {
        if (empty($mode)) {
            return $mappers;
        }

        $modeMappers = [];
        foreach ($mappers as $mapper) {
            $mapperModes = $mapper->getModes();

            $modeEnabled = $this->isModeEnabled($mapperModes, $mode);

            if ($modeEnabled) {
                $modeMappers[] = $mapper;
            }
        }
        return $modeMappers;
    }


}
